@@ -1094,7 +1094,7 @@ class Engine(object):
             move = board.pop()
             switchyard.append(move)
 
-            if board.is_zeroing(move):
+            if board.is_irreversible(move):
                 break
 
         # Validate castling rights.
